{{ Rain Demo }}

'(c)2013 Andy Schenk
' simulates raindrops and havy rain with the PM-Synth object
' if you hear at it long enough there will be a little surprise! 

CON
  _clkmode  = xtal1 + pll16x
  _xinfreq  = 5_000_000

  audioL = 10
  audioR = 11     '-1 for mono
  
OBJ
  synth :  "pm_synth_20"

VAR
  long  rndm, snd1
  long  note1, note2, rate1, rate2

  long  time, tq, ts, us
  long  ramptr
        
PUB Main
  rndm := cnt
  snd1 := synth.start(audioL,audioR,2)     'audio pins 10/11 with 20 voices
  waitcnt(clkfreq+cnt)
  bytemove(snd1+1240,@drop1,40)            'overwrite last 4 sounds with raindrop-sounds                 
  synth.prgChange(124,15)                  'drop1 sound on channel 16
  synth.prgChange(125,14)                  'drop2 sound on channel 15
  synth.prgChange(126,13)                  'noise sound on channel 14
  synth.prgChange(127,12)                  'noise2 sound on channel 13

  repeat 2
    slowDrops
    MoreDrops
    Rain
  play(@storm)
  synth.noteOff(45,12)  
  

pub slowDrops : rate
  repeat rate from 14 to 2
    rndm?
    note1 := (rndm & 1) + 47
    rate1 := (rndm & $FF_0000) + $FFFF
    rate1 *= rate
    synth.noteOn(note1,15,70)
    waitcnt(clkfreq/18+cnt)
    synth.noteOn(note1+5,14,20)
    synth.noteOff(note1,15)
    waitcnt(rate1+cnt)
    synth.noteOff(note1+5,14)

pub moreDrops : rate   
  repeat 16
    rndm?
    note1 := (rndm & 1) + 47
    note2 := (rndm>>10 & 1) + 52
    rate1 := (rndm & $FF_0000) + $FFFF
    synth.noteOn(note1,15,90)
    waitcnt(rate1+cnt)
    if note1 & 1
      synth.noteOn(note2,14,80)
      waitcnt(clkfreq/10+cnt)
    synth.noteOff(note1,15)
    synth.noteOff(note2,14)
    waitcnt(rate1+cnt)

pub rain : vol | ch
  vol := 51
  ch := 13
  repeat 2
    synth.noteOn(45,ch--,vol)
    repeat 140
      rndm?
      note1 := (rndm & 1) + 46
      note2 := (rndm>>10 & 1) + 51
      rate1 := (rndm & $FF_000) + $FFFF
      rate1 *= 3
      synth.noteOn(note1,15,80)
      waitcnt(rate1+cnt)
      if note1 & 1
        synth.noteOn(note2,14,60)
        waitcnt(clkfreq/10+cnt)
      synth.noteOff(note1,15)
      synth.noteOff(note2,14)
      waitcnt(rate1+cnt)
    vol += 20
  synth.noteOff(45,12)  
  synth.allOff


PUB play(pntr)  | lg, dt, b, v, st, d1, d2, ch
    ramptr := pntr
    us := clkfreq / 1_000_000                           'ticks / microsecond
    b := st := d1 := d2 := v := 0
    pread(@v,4)
    if v == "M" + "T"<<8 + "h"<<16 + "d"<<24            'Header ID
      pread(@v,4)                                       'Header Len
      v~
      pread(@v,2)                                       'Format
      if v == 0
        pread(@v,2)                                     'Tracks
        pread(@v,2)                                     'Ticks/Quarter
        tq := v>>8 + (v&255)<<8
        ts := 500_000 / tq                              'default Tempo 120 BPM
        pread(@v,4)                                     '"MTrk"
        pread(@v,4)                                     'Track length
        lg := v>>24 + (v>>16&255)<<8 + (v>>8&255)<<16
        time := cnt
        synth.noteOn(45,12,30)
        repeat
          pread(@b,1)                                   'get delta time
          lg--
          dt := b & $7F
          repeat while b>127
            pread(@b,1)
            lg--
            dt := dt<<7 + (b & $7F)
          time := time + dt*us*ts
          repeat until time-cnt < 0                     'wait deltatime
          b~
          pread(@b,1)                                   'MIDI byte
          if b > 127
            st := b                                     'new status byte
          elseif st==$FF
            st~
          ch := st & $0F
          d1~
          d2~
          case st & $F0                                 'decode MIDI Event
            $90: pread(@d1,1)                           'Note 
                 pread(@d2,1)                           'Velocity
                 lg -= 3
                 if d2>0
                   synth.noteOn(d1,ch,d2)               'Note On
                 else
                   synth.noteOff(d1,ch)                 'Note Off if Vel=0
            $80: pread(@d1,1)                           'Note Off 
                 pread(@d2,1)                           'Velocity
                 lg -= 3
                 synth.noteOff(d1,ch)
            $A0: pread(@d1,1)                           'Poly AfterTouch 
                 pread(@d2,1)                           '(not supported)
                 lg -= 3
            $C0: pread(@d1,1)                           'Prg Change 
                 lg -= 2
                 synth.prgChange(d1,ch)
            $D0: pread(@d1,1)                           'Mono AfterTouch 
                 lg -= 2                                '(not supported)
            $B0: pread(@d1,1)                           'Controller (nr) 
                 pread(@d2,1)                           'value
                 lg -= 3
                 if d1==7
                   synth.volContr(d2,ch)                '7=Vol
            $E0: pread(@d1,1)                           'Pitch Bender 
                 pread(@d2,1)                           '(not supported!)
                 lg -= 3
            $F0: pread(@d1,1)                           'Meta Event
                 pread(@b,1)                            'Len
                 lg -= 2
                 v~
                 repeat while b>0                       'read meta data
                   pread(@d2,1)
                   v := v<<8 + d2
                   b--
                   lg--
                   if d1==5 and v&$80 > 0
                     quit
                 if d1==81                              'Tempo
                   ts := v / tq
        until lg < 1
    synth.allOff

PUB pread(rptr,size)                                    ''Read RAM data
  repeat size
    byte[rptr++] := byte[ramptr++]
  
DAT
drop1   byte 200,48, 24,0,53, 5,2, 220,240,0 
drop2   byte 200,72, 15,0,53, 4,3, 245,227,0 
noise1  byte 100,64, 128,128,0, 0,0, 2,7,160
noise2  byte 100,48, 128,129,0, 0,0, 2,7,160

storm
  byte $4D,$54,$68,$64,$00,$00,$00,$06,$00,$00,$00,$01,$00,$78,$4D,$54
  byte $72,$6B,$00,$00,$AF,$9F,$00,$FF,$21,$01,$00,$00,$FF,$21,$01,$00
  byte $00,$FF,$21,$01,$00,$00,$FF,$21,$01,$00,$00,$FF,$21,$01,$00,$00
  byte $FF,$21,$01,$00,$00,$FF,$21,$01,$00,$00,$FF,$21,$01,$00,$00,$FF
  byte $21,$01,$00,$00,$FF,$21,$01,$00,$00,$FF,$21,$01,$00,$00,$FF,$21
  byte $01,$00,$00,$FF,$21,$01,$00,$00,$FF,$21,$01,$00,$00,$FF,$21,$01
  byte $00,$00,$FF,$21,$01,$00,$00,$FF,$21,$01,$00,$00,$FF,$21,$01,$00
  byte $00,$FF,$58,$04,$04,$02,$18,$08,$00,$FF,$59,$02,$01,$00,$00,$FF
  byte $51,$03,$08,$F9,$CB,$00,$FF,$06,$05,$49,$6E,$74,$72,$6F,$00,$B0
  byte $00,$00,$00,$B0,$00,$00,$00,$C0,$7A,$00,$B0,$07,$50,$00,$B1,$00
  byte $00,$00,$B1,$00,$00,$00,$C1,$23,$00,$B1,$07,$6E,$00,$B2,$00,$00
  byte $00,$B2,$00,$00,$00,$C2,$04,$00,$B2,$07,$78,$00,$B3,$00,$00,$00
  byte $B3,$00,$00,$00,$C3,$7A,$00,$B3,$07,$50,$00,$B4,$00,$00,$00,$B4
  byte $00,$00,$00,$C4,$7A,$00,$B4,$07,$50,$00,$B5,$00,$00,$00,$B5,$00
  byte $00,$00,$C5,$7A,$00,$B5,$07,$50,$00,$B9,$00,$00,$00,$B9,$00,$00
  byte $00,$C9,$00,$00,$B9,$07,$64,$00,$B6,$00,$00,$00,$B6,$00,$00,$00
  byte $C6,$41,$00,$B6,$07,$7F,$00,$B7,$00,$00,$00,$B7,$00,$00,$00,$C7
  byte $1E,$00,$B7,$07,$78,$00,$B8,$00,$00,$00,$B8,$00,$00,$00,$C8,$05
  byte $00,$B8,$07,$7F,$83,$60,$90,$48,$7F,$00,$90,$54,$7F,$00,$93,$54
  byte $7F,$00,$93,$60,$7F,$78,$94,$60,$7F,$00,$95,$54,$7F,$78,$94,$30
  byte $7F,$00,$95,$24,$7F,$85,$50,$91,$1C,$6E,$00,$92,$34,$71,$00,$99
  byte $23,$64,$00,$99,$33,$54,$0F,$99,$33,$00,$00,$99,$23,$00,$2C,$91
  byte $1C,$00,$01,$91,$23,$5A,$36,$91,$23,$00,$06,$91,$1F,$64,$00,$99
  byte $2A,$54,$00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99
  byte $4C,$64,$0F,$99,$4C,$00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99
  byte $33,$00,$00,$99,$45,$00,$2B,$91,$1F,$00,$02,$91,$23,$54,$00,$99
  byte $33,$34,$0F,$99,$33,$00,$26,$91,$23,$00,$07,$91,$1C,$68,$00,$99
  byte $33,$54,$0F,$99,$33,$00,$2C,$91,$1C,$00,$01,$91,$21,$5A,$00,$99
  byte $33,$34,$0F,$99,$33,$00,$27,$91,$21,$00,$06,$91,$25,$64,$00,$99
  byte $2A,$54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99,$4C,$54,$0F,$99
  byte $4C,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$2B,$91
  byte $25,$00,$02,$91,$21,$50,$00,$99,$33,$34,$0F,$99,$33,$00,$26,$91
  byte $21,$00,$07,$91,$1C,$6E,$00,$99,$23,$64,$00,$99,$33,$54,$0F,$99
  byte $33,$00,$00,$99,$23,$00,$2C,$91,$1C,$00,$01,$91,$23,$5A,$00,$99
  byte $33,$34,$0F,$99,$33,$00,$27,$91,$23,$00,$06,$91,$1F,$64,$00,$99
  byte $2A,$54,$00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99
  byte $4C,$64,$0F,$99,$4C,$00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99
  byte $33,$00,$00,$99,$45,$00,$2B,$91,$1F,$00,$02,$91,$23,$54,$00,$99
  byte $33,$34,$0F,$99,$33,$00,$1B,$92,$34,$00,$0B,$91,$23,$00,$07,$91
  byte $1C,$68,$00,$99,$33,$54,$0F,$99,$33,$00,$2C,$91,$1C,$00,$01,$91
  byte $21,$5A,$00,$99,$33,$34,$0E,$99,$33,$00,$28,$91,$21,$00,$06,$91
  byte $25,$64,$00,$92,$4C,$71,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99
  byte $45,$24,$00,$99,$4C,$54,$0F,$99,$4C,$00,$00,$99,$2A,$00,$00,$99
  byte $33,$00,$00,$99,$45,$00,$0F,$92,$51,$77,$1C,$91,$25,$00,$02,$91
  byte $21,$50,$00,$92,$53,$71,$00,$99,$33,$34,$0F,$99,$33,$00,$0F,$92
  byte $58,$77,$0C,$90,$54,$00,$00,$90,$48,$00,$00,$93,$60,$00,$00,$93
  byte $54,$00,$0B,$91,$21,$00,$07,$91,$1C,$6E,$00,$92,$53,$00,$00,$92
  byte $53,$77,$00,$99,$23,$64,$00,$99,$33,$54,$0F,$99,$33,$00,$00,$99
  byte $23,$00,$2C,$91,$1C,$00,$01,$91,$23,$5A,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$27,$91,$23,$00,$06,$91,$1F,$64,$00,$99,$2A,$54,$00,$99
  byte $33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$64,$0F,$99
  byte $4C,$00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99
  byte $45,$00,$2B,$91,$1F,$00,$02,$91,$23,$54,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$26,$91,$23,$00,$07,$91,$1C,$68,$00,$99,$33,$54,$0F,$99
  byte $33,$00,$2C,$91,$1C,$00,$01,$91,$21,$5A,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$27,$91,$21,$00,$06,$91,$25,$64,$00,$99,$2A,$54,$00,$99
  byte $33,$44,$00,$99,$45,$24,$00,$99,$4C,$54,$0F,$99,$4C,$00,$00,$99
  byte $2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$2B,$91,$25,$00,$02,$91
  byte $21,$50,$00,$99,$33,$34,$0F,$99,$33,$00,$26,$91,$21,$00,$07,$91
  byte $1C,$6E,$00,$99,$23,$64,$00,$99,$33,$54,$0F,$99,$33,$00,$00,$99
  byte $23,$00,$2C,$91,$1C,$00,$01,$91,$23,$5A,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$27,$91,$23,$00,$06,$91,$1F,$64,$00,$99,$2A,$54,$00,$99
  byte $33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$64,$0F,$99
  byte $4C,$00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99
  byte $45,$00,$2B,$91,$1F,$00,$02,$91,$23,$54,$00,$99,$33,$34,$0C,$92
  byte $51,$00,$03,$99,$33,$00,$11,$92,$4C,$00,$02,$92,$58,$00,$13,$91
  byte $23,$00,$00,$92,$53,$00,$07,$91,$1C,$68,$00,$99,$33,$54,$0F,$99
  byte $33,$00,$2C,$91,$1C,$00,$01,$91,$21,$5A,$00,$92,$4F,$63,$00,$99
  byte $33,$34,$0E,$99,$33,$00,$09,$92,$4F,$00,$07,$92,$51,$71,$17,$92
  byte $51,$00,$01,$91,$21,$00,$06,$91,$25,$64,$00,$92,$4F,$71,$00,$99
  byte $2A,$54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99,$4C,$54,$0F,$99
  byte $4C,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$08,$92
  byte $4F,$00,$07,$92,$4E,$63,$17,$92,$4E,$00,$05,$91,$25,$00,$02,$91
  byte $21,$50,$00,$92,$4C,$67,$00,$99,$33,$34,$0F,$99,$33,$00,$08,$92
  byte $4C,$00,$07,$92,$4E,$63,$17,$92,$4E,$00,$01,$91,$21,$00,$06,$91
  byte $1C,$6E,$00,$92,$4F,$71,$00,$99,$23,$64,$00,$99,$33,$54,$0F,$99
  byte $33,$00,$00,$99,$23,$00,$08,$92,$4F,$00,$07,$92,$4A,$4F,$17,$92
  byte $4A,$00,$06,$91,$1C,$00,$01,$91,$23,$5A,$00,$92,$4E,$71,$00,$99
  byte $33,$34,$0F,$99,$33,$00,$08,$92,$4E,$00,$1F,$91,$23,$00,$06,$91
  byte $1F,$64,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$36,$64,$00,$99
  byte $45,$34,$00,$99,$4C,$64,$0F,$99,$4C,$00,$00,$99,$36,$00,$00,$99
  byte $2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$2B,$91,$1F,$00,$02,$91
  byte $23,$54,$00,$92,$4A,$71,$00,$99,$33,$34,$0F,$99,$33,$00,$26,$91
  byte $23,$00,$07,$91,$1C,$68,$00,$99,$33,$54,$0F,$99,$33,$00,$26,$92
  byte $4A,$00,$06,$91,$1C,$00,$01,$91,$21,$5A,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$27,$91,$21,$00,$01,$92,$4A,$59,$05,$91,$25,$64,$00,$92
  byte $4C,$71,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99
  byte $4C,$54,$03,$92,$4A,$00,$0C,$99,$4C,$00,$00,$99,$2A,$00,$00,$99
  byte $33,$00,$00,$99,$45,$00,$2B,$91,$25,$00,$02,$91,$21,$50,$00,$99
  byte $33,$34,$0F,$99,$33,$00,$26,$91,$21,$00,$07,$90,$48,$7F,$00,$90
  byte $54,$7F,$00,$91,$1C,$6E,$00,$93,$54,$7F,$00,$93,$60,$7F,$00,$99
  byte $23,$64,$00,$99,$33,$54,$0F,$99,$33,$00,$00,$99,$23,$00,$2C,$91
  byte $1C,$00,$01,$91,$23,$5A,$00,$99,$33,$34,$0F,$99,$33,$00,$26,$92
  byte $4C,$00,$01,$91,$23,$00,$06,$91,$1F,$64,$00,$99,$2A,$54,$00,$99
  byte $33,$64,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$64,$0F,$99
  byte $4C,$00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99
  byte $45,$00,$2B,$91,$1F,$00,$02,$91,$23,$54,$00,$99,$33,$74,$0F,$99
  byte $33,$00,$26,$91,$23,$00,$07,$91,$1C,$68,$00,$99,$33,$54,$0F,$99
  byte $33,$00,$2C,$91,$1C,$00,$01,$91,$21,$5A,$00,$99,$33,$54,$0E,$99
  byte $33,$00,$28,$91,$21,$00,$06,$91,$25,$64,$00,$99,$2A,$54,$00,$99
  byte $33,$44,$00,$99,$45,$24,$00,$99,$4C,$54,$0F,$99,$4C,$00,$00,$99
  byte $2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$2B,$91,$25,$00,$02,$91
  byte $21,$50,$00,$99,$33,$34,$0F,$99,$33,$00,$26,$91,$21,$00,$07,$91
  byte $1C,$6E,$00,$92,$5F,$71,$00,$99,$23,$64,$00,$99,$33,$54,$0F,$99
  byte $33,$00,$00,$99,$23,$00,$0F,$92,$5B,$6D,$12,$92,$5F,$00,$0B,$91
  byte $1C,$00,$01,$91,$23,$5A,$00,$92,$5D,$71,$00,$99,$33,$34,$0E,$99
  byte $33,$00,$04,$92,$5B,$00,$0C,$92,$5A,$6D,$12,$92,$5D,$00,$06,$91
  byte $23,$00,$06,$91,$1F,$64,$00,$92,$5B,$71,$00,$99,$2A,$54,$00,$99
  byte $33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$64,$0F,$99
  byte $4C,$00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99
  byte $45,$00,$03,$92,$5A,$00,$0C,$92,$58,$6D,$12,$92,$5B,$00,$0A,$91
  byte $1F,$00,$02,$91,$23,$54,$00,$92,$5A,$71,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$03,$92,$58,$00,$0C,$92,$56,$6D,$12,$92,$5A,$00,$05,$91
  byte $23,$00,$07,$91,$1C,$68,$00,$92,$58,$71,$00,$99,$33,$54,$0F,$99
  byte $33,$00,$03,$92,$56,$00,$0C,$92,$55,$6D,$12,$92,$58,$00,$0B,$91
  byte $1C,$00,$01,$91,$21,$5A,$00,$92,$56,$71,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$03,$92,$55,$00,$0C,$92,$53,$6D,$12,$92,$56,$00,$06,$91
  byte $21,$00,$06,$91,$25,$64,$00,$92,$55,$71,$00,$99,$2A,$54,$00,$99
  byte $33,$44,$00,$99,$45,$24,$00,$99,$4C,$54,$0F,$99,$4C,$00,$00,$99
  byte $2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$03,$92,$53,$00,$0C,$92
  byte $51,$6D,$12,$92,$55,$00,$0A,$91,$25,$00,$02,$91,$21,$50,$00,$92
  byte $53,$71,$00,$99,$33,$34,$0F,$99,$33,$00,$03,$92,$51,$00,$0C,$92
  byte $4F,$6D,$12,$92,$53,$00,$05,$91,$21,$00,$07,$91,$1C,$6E,$00,$92
  byte $51,$71,$00,$99,$23,$64,$00,$99,$33,$54,$0F,$99,$33,$00,$00,$99
  byte $23,$00,$03,$92,$4F,$00,$0C,$92,$4E,$6D,$12,$92,$51,$00,$0B,$91
  byte $1C,$00,$01,$91,$23,$5A,$00,$92,$4F,$71,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$03,$92,$4E,$00,$0C,$92,$4C,$6D,$12,$92,$4F,$00,$06,$91
  byte $23,$00,$06,$91,$1F,$64,$00,$92,$4E,$71,$00,$99,$33,$44,$0F,$99
  byte $33,$00,$03,$92,$4C,$00,$0C,$92,$4A,$6D,$12,$92,$4E,$00,$0A,$91
  byte $1F,$00,$02,$91,$23,$54,$00,$92,$4C,$71,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$03,$92,$4A,$00,$0C,$92,$49,$6D,$12,$92,$4C,$00,$05,$91
  byte $23,$00,$07,$91,$1C,$68,$00,$92,$4A,$71,$00,$99,$33,$54,$0F,$99
  byte $33,$00,$03,$92,$49,$00,$0C,$92,$47,$6D,$12,$92,$4A,$00,$0B,$91
  byte $1C,$00,$01,$91,$21,$5A,$00,$92,$49,$71,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$03,$92,$47,$00,$0C,$92,$45,$6D,$12,$92,$49,$00,$06,$91
  byte $21,$00,$06,$91,$25,$64,$00,$92,$47,$71,$00,$99,$2A,$54,$00,$99
  byte $33,$44,$00,$99,$45,$24,$00,$99,$4C,$54,$0F,$99,$4C,$00,$00,$99
  byte $2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$03,$92,$45,$00,$0C,$92
  byte $43,$6D,$00,$99,$33,$34,$0F,$99,$33,$00,$03,$92,$47,$00,$0A,$91
  byte $25,$00,$02,$91,$21,$50,$00,$92,$45,$71,$00,$99,$33,$44,$0F,$99
  byte $33,$00,$03,$92,$43,$00,$0C,$92,$42,$6D,$12,$92,$45,$00,$05,$91
  byte $21,$00,$07,$91,$1C,$6E,$00,$92,$43,$71,$00,$99,$23,$64,$00,$99
  byte $33,$54,$01,$94,$48,$60,$00,$95,$3C,$60,$0E,$99,$33,$00,$00,$99
  byte $23,$00,$03,$92,$42,$00,$0C,$92,$40,$6D,$12,$92,$43,$00,$0B,$91
  byte $1C,$00,$01,$91,$23,$5A,$00,$92,$42,$71,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$03,$92,$40,$00,$0C,$92,$3E,$6D,$0C,$94,$30,$00,$00,$94
  byte $60,$00,$00,$95,$24,$00,$00,$95,$54,$00,$06,$92,$42,$00,$06,$91
  byte $23,$00,$06,$91,$1F,$64,$00,$92,$40,$71,$00,$99,$2A,$54,$00,$99
  byte $33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$64,$0F,$99
  byte $4C,$00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99
  byte $45,$00,$02,$92,$3E,$00,$0D,$92,$3D,$6D,$12,$92,$40,$00,$0A,$91
  byte $1F,$00,$02,$91,$23,$54,$00,$92,$3E,$71,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$03,$92,$3D,$00,$0C,$92,$3B,$6D,$12,$92,$3E,$00,$05,$91
  byte $23,$00,$07,$91,$1C,$68,$00,$92,$3D,$71,$00,$99,$33,$54,$0F,$99
  byte $33,$00,$03,$92,$3B,$00,$0C,$92,$39,$6D,$12,$92,$3D,$00,$0B,$91
  byte $1C,$00,$01,$91,$21,$5A,$00,$92,$3B,$71,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$03,$92,$39,$00,$1E,$92,$3B,$00,$06,$91,$21,$00,$06,$91
  byte $25,$64,$00,$92,$3E,$71,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99
  byte $45,$24,$00,$99,$4C,$54,$01,$92,$36,$71,$00,$92,$39,$71,$0E,$99
  byte $4C,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$2B,$91
  byte $25,$00,$02,$91,$21,$50,$00,$99,$33,$34,$0F,$99,$33,$00,$03,$92
  byte $36,$00,$00,$92,$3E,$00,$01,$92,$39,$00,$22,$91,$21,$00,$06,$90
  byte $54,$00,$00,$90,$48,$00,$00,$93,$60,$00,$00,$93,$54,$00,$01,$91
  byte $1C,$6E,$00,$92,$3B,$71,$00,$92,$40,$71,$00,$99,$23,$64,$00,$99
  byte $33,$54,$01,$92,$34,$71,$00,$92,$37,$71,$0E,$99,$33,$00,$00,$99
  byte $23,$00,$2C,$91,$1C,$00,$01,$91,$23,$5A,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$27,$91,$23,$00,$06,$91,$1F,$64,$00,$99,$2A,$54,$00,$99
  byte $33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$64,$0F,$99
  byte $4C,$00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99
  byte $45,$00,$02,$92,$34,$00,$01,$92,$3B,$00,$00,$92,$40,$00,$00,$92
  byte $37,$00,$28,$91,$1F,$00,$02,$91,$23,$54,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$26,$91,$23,$00,$07,$91,$1C,$68,$00,$99,$33,$54,$0F,$99
  byte $33,$00,$2C,$91,$1C,$00,$01,$91,$21,$5A,$00,$99,$33,$34,$0E,$99
  byte $33,$00,$28,$91,$21,$00,$06,$91,$25,$64,$00,$92,$3E,$67,$00,$99
  byte $2A,$54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99,$4C,$54,$01,$92
  byte $36,$67,$00,$92,$39,$67,$0E,$99,$4C,$00,$00,$99,$2A,$00,$00,$99
  byte $33,$00,$00,$99,$45,$00,$2B,$91,$25,$00,$02,$91,$21,$50,$00,$99
  byte $33,$34,$0F,$99,$33,$00,$03,$92,$36,$00,$00,$92,$3E,$00,$01,$92
  byte $39,$00,$22,$91,$21,$00,$07,$91,$1C,$6E,$00,$92,$3B,$63,$00,$92
  byte $40,$63,$00,$99,$23,$64,$00,$99,$33,$54,$01,$92,$34,$63,$00,$92
  byte $37,$63,$0E,$99,$33,$00,$00,$99,$23,$00,$2C,$91,$1C,$00,$01,$91
  byte $23,$5A,$00,$99,$33,$34,$0F,$99,$33,$00,$27,$91,$23,$00,$06,$91
  byte $1F,$64,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$36,$64,$00,$99
  byte $45,$34,$00,$99,$4C,$64,$0F,$99,$4C,$00,$00,$99,$36,$00,$00,$99
  byte $2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$03,$92,$37,$00,$00,$92
  byte $3B,$00,$00,$92,$40,$00,$00,$92,$34,$00,$28,$91,$1F,$00,$02,$91
  byte $23,$54,$00,$99,$33,$34,$0F,$99,$33,$00,$26,$91,$23,$00,$07,$91
  byte $1C,$68,$00,$99,$33,$54,$0F,$99,$33,$00,$2C,$91,$1C,$00,$01,$91
  byte $21,$5A,$00,$99,$33,$34,$0F,$99,$33,$00,$27,$91,$21,$00,$06,$91
  byte $25,$64,$00,$92,$39,$67,$00,$92,$3E,$67,$00,$99,$2A,$54,$00,$99
  byte $33,$44,$00,$99,$45,$24,$00,$99,$4C,$54,$01,$92,$36,$67,$0E,$99
  byte $4C,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$2B,$91
  byte $25,$00,$02,$91,$21,$50,$00,$99,$33,$34,$0F,$99,$33,$00,$03,$92
  byte $3E,$00,$00,$92,$39,$00,$01,$92,$36,$00,$22,$91,$21,$00,$07,$90
  byte $48,$69,$00,$90,$54,$69,$00,$91,$1C,$6E,$00,$92,$3B,$5D,$00,$92
  byte $40,$5D,$00,$93,$54,$69,$00,$93,$60,$69,$00,$99,$23,$64,$00,$99
  byte $33,$54,$01,$92,$34,$5D,$00,$92,$37,$5D,$0E,$99,$33,$00,$00,$99
  byte $23,$00,$2C,$91,$1C,$00,$01,$91,$23,$5A,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$27,$91,$23,$00,$06,$91,$1F,$64,$00,$99,$2A,$54,$00,$99
  byte $33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$64,$0F,$99
  byte $4C,$00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99
  byte $45,$00,$2B,$91,$1F,$00,$02,$91,$23,$54,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$26,$91,$23,$00,$07,$91,$1C,$68,$00,$99,$33,$54,$0F,$99
  byte $33,$00,$2C,$91,$1C,$00,$01,$91,$21,$5A,$00,$99,$33,$34,$0E,$99
  byte $33,$00,$28,$91,$21,$00,$06,$91,$25,$64,$00,$92,$3E,$67,$00,$99
  byte $2A,$54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99,$4C,$54,$01,$92
  byte $36,$67,$00,$92,$39,$67,$0D,$92,$37,$00,$00,$92,$34,$00,$00,$92
  byte $3B,$00,$00,$92,$40,$00,$01,$99,$4C,$00,$00,$99,$2A,$00,$00,$99
  byte $33,$00,$00,$99,$45,$00,$2B,$91,$25,$00,$02,$91,$21,$50,$00,$99
  byte $33,$34,$0F,$99,$33,$00,$03,$92,$39,$00,$00,$92,$3E,$00,$01,$92
  byte $36,$00,$22,$91,$21,$00,$07,$91,$1C,$6E,$00,$92,$3B,$5D,$00,$92
  byte $40,$5D,$00,$99,$23,$64,$00,$99,$33,$54,$01,$92,$34,$5D,$00,$92
  byte $37,$5D,$0E,$99,$33,$00,$00,$99,$23,$00,$2C,$91,$1C,$00,$01,$91
  byte $23,$5A,$00,$99,$33,$34,$0F,$99,$33,$00,$27,$91,$23,$00,$06,$91
  byte $1F,$64,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$36,$64,$00,$99
  byte $45,$34,$00,$99,$4C,$64,$0F,$99,$4C,$00,$00,$99,$36,$00,$00,$99
  byte $2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$02,$92,$34,$00,$01,$92
  byte $3B,$00,$00,$92,$40,$00,$00,$92,$37,$00,$28,$91,$1F,$00,$02,$91
  byte $23,$54,$00,$99,$33,$34,$0F,$99,$33,$00,$26,$91,$23,$00,$07,$91
  byte $1C,$68,$00,$99,$33,$54,$0F,$99,$33,$00,$2C,$91,$1C,$00,$01,$91
  byte $21,$5A,$00,$99,$33,$34,$0F,$99,$33,$00,$27,$91,$21,$00,$06,$91
  byte $25,$64,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99
  byte $4C,$54,$0F,$99,$4C,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99
  byte $45,$00,$2B,$91,$25,$00,$02,$91,$21,$50,$00,$99,$33,$34,$0F,$99
  byte $33,$00,$26,$91,$21,$00,$07,$FF,$06,$07,$56,$65,$72,$73,$65,$20
  byte $31,$00,$91,$1C,$6E,$00,$92,$40,$5D,$00,$99,$23,$64,$00,$99,$31
  byte $64,$00,$99,$33,$54,$00,$96,$40,$64,$01,$92,$34,$5D,$00,$92,$37
  byte $5D,$00,$92,$3B,$5D,$0E,$99,$33,$00,$00,$99,$31,$00,$00,$99,$23
  byte $00,$2C,$91,$1C,$00,$00,$96,$40,$00,$01,$91,$23,$5A,$00,$99,$33
  byte $34,$00,$96,$40,$64,$0F,$99,$33,$00,$27,$91,$23,$00,$05,$96,$40
  byte $00,$01,$91,$1F,$64,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$36
  byte $64,$00,$99,$45,$34,$00,$99,$4C,$7F,$00,$96,$43,$64,$0F,$99,$4C
  byte $00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45
  byte $00,$02,$92,$34,$00,$01,$92,$40,$00,$00,$92,$37,$00,$00,$92,$3B
  byte $00,$28,$91,$1F,$00,$01,$96,$43,$00,$01,$91,$23,$54,$00,$99,$33
  byte $34,$00,$96,$3E,$64,$0F,$99,$33,$00,$26,$91,$23,$00,$06,$96,$3E
  byte $00,$01,$91,$1C,$68,$00,$99,$33,$54,$00,$96,$40,$64,$0F,$99,$33
  byte $00,$2C,$91,$1C,$00,$01,$91,$21,$5A,$00,$99,$33,$34,$0E,$99,$33
  byte $00,$28,$91,$21,$00,$06,$91,$25,$64,$00,$92,$3E,$59,$00,$99,$2A
  byte $54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99,$4C,$74,$01,$92,$36
  byte $59,$00,$92,$39,$59,$0E,$99,$4C,$00,$00,$99,$2A,$00,$00,$99,$33
  byte $00,$00,$99,$45,$00,$2B,$91,$25,$00,$02,$91,$21,$50,$00,$99,$33
  byte $34,$0F,$99,$33,$00,$03,$92,$36,$00,$00,$92,$3E,$00,$01,$92,$39
  byte $00,$22,$91,$21,$00,$06,$96,$40,$00,$01,$91,$1C,$6E,$00,$92,$3B
  byte $5D,$00,$92,$40,$5D,$00,$99,$23,$64,$00,$99,$33,$54,$01,$92,$34
  byte $5D,$00,$92,$37,$5D,$0E,$99,$33,$00,$00,$99,$23,$00,$2C,$91,$1C
  byte $00,$01,$91,$23,$5A,$00,$99,$33,$34,$0E,$99,$33,$00,$28,$91,$23
  byte $00,$06,$91,$1F,$64,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$36
  byte $64,$00,$99,$45,$34,$00,$99,$4C,$7F,$0F,$99,$4C,$00,$00,$99,$36
  byte $00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$03,$92,$37
  byte $00,$00,$92,$3B,$00,$00,$92,$40,$00,$00,$92,$34,$00,$28,$91,$1F
  byte $00,$02,$91,$23,$54,$00,$99,$33,$34,$0F,$99,$33,$00,$26,$91,$23
  byte $00,$07,$91,$1C,$68,$00,$99,$33,$54,$0F,$99,$33,$00,$2C,$91,$1C
  byte $00,$01,$91,$21,$5A,$00,$99,$33,$34,$0F,$99,$33,$00,$27,$91,$21
  byte $00,$06,$91,$25,$64,$00,$92,$39,$59,$00,$92,$3E,$59,$00,$99,$2A
  byte $54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99,$4C,$74,$01,$92,$36
  byte $59,$0E,$99,$4C,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45
  byte $00,$2B,$91,$25,$00,$02,$91,$21,$50,$00,$99,$33,$34,$0F,$99,$33
  byte $00,$03,$92,$3E,$00,$00,$92,$39,$00,$01,$92,$36,$00,$22,$91,$21
  byte $00,$06,$90,$54,$00,$00,$90,$48,$00,$00,$93,$60,$00,$00,$93,$54
  byte $00,$01,$90,$48,$50,$00,$91,$1C,$6E,$00,$92,$40,$5D,$00,$93,$54
  byte $50,$00,$99,$23,$64,$00,$99,$33,$54,$00,$96,$40,$64,$01,$92,$34
  byte $5D,$00,$92,$37,$5D,$00,$92,$3B,$5D,$0E,$99,$33,$00,$00,$99,$23
  byte $00,$2C,$91,$1C,$00,$00,$96,$40,$00,$01,$91,$23,$5A,$00,$99,$33
  byte $34,$00,$96,$40,$64,$0F,$99,$33,$00,$27,$91,$23,$00,$05,$96,$40
  byte $00,$01,$91,$1F,$64,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$36
  byte $64,$00,$99,$45,$34,$00,$99,$4C,$7F,$00,$96,$43,$64,$0F,$99,$4C
  byte $00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45
  byte $00,$02,$92,$34,$00,$01,$92,$40,$00,$00,$92,$37,$00,$00,$92,$3B
  byte $00,$28,$91,$1F,$00,$01,$96,$43,$00,$01,$91,$23,$54,$00,$99,$33
  byte $34,$00,$96,$3E,$64,$0F,$99,$33,$00,$26,$91,$23,$00,$06,$96,$3E
  byte $00,$01,$91,$1C,$68,$00,$99,$33,$54,$00,$96,$40,$64,$0F,$99,$33
  byte $00,$2C,$91,$1C,$00,$01,$91,$21,$5A,$00,$99,$33,$34,$0E,$99,$33
  byte $00,$28,$91,$21,$00,$06,$91,$25,$64,$00,$92,$3E,$59,$00,$99,$2A
  byte $54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99,$4C,$74,$01,$92,$36
  byte $59,$00,$92,$39,$59,$0E,$99,$4C,$00,$00,$99,$2A,$00,$00,$99,$33
  byte $00,$00,$99,$45,$00,$2B,$91,$25,$00,$02,$91,$21,$50,$00,$99,$33
  byte $34,$0F,$99,$33,$00,$03,$92,$36,$00,$00,$92,$3E,$00,$01,$92,$39
  byte $00,$22,$91,$21,$00,$06,$96,$40,$00,$01,$91,$1C,$6E,$00,$92,$3B
  byte $5D,$00,$92,$40,$5D,$00,$99,$23,$64,$00,$99,$33,$54,$01,$92,$34
  byte $5D,$00,$92,$37,$5D,$0E,$99,$33,$00,$00,$99,$23,$00,$2C,$91,$1C
  byte $00,$01,$91,$23,$5A,$00,$99,$33,$34,$0F,$99,$33,$00,$27,$91,$23
  byte $00,$06,$91,$1F,$64,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$36
  byte $64,$00,$99,$45,$34,$00,$99,$4C,$7F,$0F,$99,$4C,$00,$00,$99,$36
  byte $00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$03,$92,$37
  byte $00,$00,$92,$3B,$00,$00,$92,$40,$00,$00,$92,$34,$00,$28,$91,$1F
  byte $00,$02,$91,$23,$54,$00,$99,$33,$34,$0F,$99,$33,$00,$26,$91,$23
  byte $00,$07,$91,$1C,$68,$00,$99,$33,$54,$0F,$99,$33,$00,$2C,$91,$1C
  byte $00,$01,$91,$21,$5A,$00,$99,$33,$34,$0F,$99,$33,$00,$27,$91,$21
  byte $00,$06,$91,$25,$64,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$45
  byte $24,$00,$99,$4C,$74,$0F,$99,$4C,$00,$00,$99,$2A,$00,$00,$99,$33
  byte $00,$00,$99,$45,$00,$2B,$91,$25,$00,$02,$91,$21,$50,$00,$99,$33
  byte $34,$00,$96,$40,$64,$0F,$99,$33,$00,$26,$91,$21,$00,$06,$96,$40
  byte $00,$01,$91,$21,$54,$00,$92,$40,$67,$00,$92,$45,$67,$00,$99,$23
  byte $24,$00,$99,$33,$64,$00,$96,$45,$64,$01,$92,$48,$67,$0E,$99,$33
  byte $00,$00,$99,$23,$00,$08,$92,$45,$00,$00,$92,$40,$00,$01,$91,$21
  byte $00,$00,$92,$48,$00,$23,$96,$45,$00,$01,$91,$21,$46,$00,$92,$45
  byte $63,$00,$99,$23,$24,$00,$99,$33,$34,$00,$96,$45,$64,$01,$92,$40
  byte $63,$00,$92,$48,$63,$0E,$99,$33,$00,$00,$99,$23,$00,$22,$91,$21
  byte $00,$0A,$96,$45,$00,$01,$91,$2D,$50,$00,$99,$23,$24,$00,$99,$2A
  byte $54,$00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C
  byte $7F,$00,$96,$45,$64,$0F,$99,$4C,$00,$00,$99,$2A,$00,$00,$99,$33
  byte $00,$00,$99,$23,$00,$00,$99,$45,$00,$00,$99,$36,$00,$2C,$96,$45
  byte $00,$01,$99,$23,$34,$00,$99,$33,$34,$00,$96,$43,$64,$0F,$99,$33
  byte $00,$00,$99,$23,$00,$27,$92,$48,$00,$00,$92,$40,$00,$00,$92,$45
  byte $00,$05,$91,$2D,$00,$00,$96,$43,$00,$01,$91,$21,$5E,$00,$92,$42
  byte $6D,$00,$92,$47,$6D,$00,$99,$23,$34,$00,$99,$33,$54,$00,$96,$45
  byte $64,$01,$92,$4A,$6D,$0E,$99,$33,$00,$00,$99,$23,$00,$08,$92,$47
  byte $00,$00,$92,$42,$00,$01,$92,$4A,$00,$07,$91,$21,$00,$1D,$91,$21
  byte $50,$00,$92,$47,$6D,$00,$99,$23,$44,$00,$99,$33,$34,$01,$92,$42
  byte $6D,$00,$92,$4A,$6D,$0E,$99,$33,$00,$00,$99,$23,$00,$22,$91,$21
  byte $00,$0B,$91,$2D,$5A,$00,$99,$23,$44,$00,$99,$2A,$54,$00,$99,$33
  byte $44,$00,$99,$45,$24,$00,$99,$4C,$74,$0F,$99,$4C,$00,$00,$99,$33
  byte $00,$00,$99,$23,$00,$00,$99,$2A,$00,$00,$99,$45,$00,$2D,$99,$23
  byte $44,$00,$99,$33,$34,$0F,$99,$33,$00,$00,$99,$23,$00,$27,$92,$4A
  byte $00,$00,$92,$42,$00,$00,$92,$47,$00,$05,$91,$2D,$00,$00,$96,$45
  byte $00,$01,$91,$21,$64,$00,$92,$43,$71,$00,$99,$23,$54,$00,$99,$33
  byte $64,$01,$92,$48,$71,$00,$92,$4C,$71,$0E,$99,$33,$00,$00,$99,$23
  byte $00,$08,$92,$43,$00,$01,$92,$4C,$00,$00,$92,$48,$00,$0D,$91,$21
  byte $00,$17,$91,$21,$5A,$00,$92,$43,$6D,$00,$92,$48,$6D,$00,$99,$23
  byte $54,$00,$99,$33,$34,$01,$92,$4C,$6D,$0E,$99,$33,$00,$00,$99,$23
  byte $00,$25,$91,$21,$00,$08,$91,$2D,$64,$00,$99,$23,$54,$00,$99,$2A
  byte $54,$00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C
  byte $7F,$0F,$99,$4C,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$23
  byte $00,$00,$99,$45,$00,$00,$99,$36,$00,$2D,$99,$23,$64,$00,$99,$33
  byte $34,$0F,$99,$33,$00,$00,$99,$23,$00,$27,$92,$4C,$00,$00,$92,$48
  byte $00,$00,$92,$43,$00,$05,$91,$2D,$00,$01,$91,$21,$72,$00,$92,$4A
  byte $77,$00,$92,$4E,$77,$00,$99,$23,$64,$00,$99,$33,$54,$01,$92,$45
  byte $77,$0E,$99,$33,$00,$00,$99,$23,$00,$08,$92,$4E,$00,$00,$92,$4A
  byte $00,$01,$92,$45,$00,$14,$91,$21,$00,$10,$91,$21,$64,$00,$92,$45
  byte $71,$00,$99,$23,$64,$00,$99,$33,$34,$01,$92,$4A,$71,$00,$92,$4E
  byte $71,$0E,$99,$33,$00,$00,$99,$23,$00,$27,$91,$21,$00,$06,$91,$2D
  byte $72,$00,$99,$23,$74,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$45
  byte $24,$00,$99,$4C,$74,$0F,$99,$4C,$00,$00,$99,$33,$00,$00,$99,$23
  byte $00,$00,$99,$2A,$00,$00,$99,$45,$00,$2B,$91,$2D,$00,$02,$91,$21
  byte $5A,$00,$99,$23,$7F,$00,$99,$33,$34,$00,$96,$3E,$64,$0F,$99,$33
  byte $00,$00,$99,$23,$00,$26,$91,$21,$00,$01,$92,$4E,$00,$00,$92,$4A
  byte $00,$00,$92,$45,$00,$05,$90,$48,$00,$00,$93,$54,$00,$00,$96,$3E
  byte $00,$01,$91,$1C,$6E,$00,$92,$3B,$5D,$00,$92,$40,$5D,$00,$99,$23
  byte $64,$00,$99,$33,$54,$00,$96,$40,$64,$01,$92,$34,$5D,$00,$92,$37
  byte $5D,$0E,$99,$33,$00,$00,$99,$23,$00,$2C,$91,$1C,$00,$00,$96,$40
  byte $00,$01,$91,$23,$5A,$00,$99,$33,$34,$00,$96,$40,$64,$0E,$99,$33
  byte $00,$28,$91,$23,$00,$05,$96,$40,$00,$01,$91,$1F,$64,$00,$99,$2A
  byte $54,$00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C
  byte $7F,$00,$96,$43,$64,$0F,$99,$4C,$00,$00,$99,$36,$00,$00,$99,$2A
  byte $00,$00,$99,$33,$00,$00,$99,$45,$00,$03,$92,$37,$00,$00,$92,$3B
  byte $00,$00,$92,$40,$00,$00,$92,$34,$00,$28,$91,$1F,$00,$01,$96,$43
  byte $00,$01,$91,$23,$54,$00,$99,$33,$34,$00,$96,$43,$64,$0F,$99,$33
  byte $00,$26,$91,$23,$00,$06,$96,$43,$00,$01,$91,$1C,$68,$00,$99,$33
  byte $54,$00,$96,$40,$64,$0F,$99,$33,$00,$2C,$91,$1C,$00,$01,$91,$21
  byte $5A,$00,$99,$33,$34,$0E,$99,$33,$00,$28,$91,$21,$00,$06,$91,$25
  byte $64,$00,$92,$39,$59,$00,$92,$3E,$59,$00,$99,$2A,$54,$00,$99,$33
  byte $44,$00,$99,$45,$24,$00,$99,$4C,$74,$01,$92,$36,$59,$0E,$99,$4C
  byte $00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$2B,$91,$25
  byte $00,$02,$91,$21,$50,$00,$99,$33,$34,$0F,$99,$33,$00,$03,$92,$36
  byte $00,$00,$92,$3E,$00,$00,$92,$39,$00,$23,$91,$21,$00,$06,$96,$40
  byte $00,$01,$91,$1C,$6E,$00,$92,$40,$5D,$00,$99,$23,$64,$00,$99,$33
  byte $54,$01,$92,$34,$5D,$00,$92,$37,$5D,$00,$92,$3B,$5D,$0E,$99,$33
  byte $00,$00,$99,$23,$00,$2C,$91,$1C,$00,$01,$91,$23,$5A,$00,$99,$33
  byte $34,$0F,$99,$33,$00,$27,$91,$23,$00,$06,$91,$1F,$64,$00,$99,$2A
  byte $54,$00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C
  byte $7F,$0F,$99,$4C,$00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99,$33
  byte $00,$00,$99,$45,$00,$02,$92,$34,$00,$01,$92,$40,$00,$00,$92,$37
  byte $00,$00,$92,$3B,$00,$28,$91,$1F,$00,$02,$91,$23,$54,$00,$99,$33
  byte $34,$0F,$99,$33,$00,$26,$91,$23,$00,$07,$91,$1C,$68,$00,$99,$33
  byte $54,$0F,$99,$33,$00,$2C,$91,$1C,$00,$01,$91,$21,$5A,$00,$99,$33
  byte $34,$0F,$99,$33,$00,$27,$91,$21,$00,$06,$91,$25,$64,$00,$99,$2A
  byte $54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99,$4C,$74,$00,$96,$40
  byte $64,$0F,$99,$4C,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45
  byte $00,$2B,$91,$25,$00,$01,$96,$40,$00,$01,$91,$21,$50,$00,$99,$33
  byte $34,$00,$96,$40,$64,$0F,$99,$33,$00,$26,$91,$21,$00,$06,$96,$40
  byte $00,$01,$91,$26,$6E,$00,$92,$43,$71,$00,$92,$47,$71,$00,$92,$3E
  byte $71,$00,$99,$23,$64,$00,$99,$33,$64,$00,$96,$47,$64,$0F,$99,$33
  byte $00,$00,$99,$23,$00,$2C,$96,$47,$00,$01,$96,$45,$64,$01,$92,$47
  byte $00,$01,$92,$3E,$00,$00,$92,$43,$00,$25,$91,$26,$00,$14,$96,$45
  byte $00,$01,$91,$26,$6E,$00,$92,$42,$71,$00,$92,$45,$71,$00,$99,$23
  byte $64,$00,$99,$2A,$54,$00,$99,$33,$64,$00,$99,$36,$64,$00,$99,$45
  byte $34,$00,$96,$45,$64,$01,$92,$3E,$71,$0E,$99,$45,$00,$00,$99,$33
  byte $00,$00,$99,$23,$00,$00,$99,$2A,$00,$00,$99,$36,$00,$2C,$96,$45
  byte $00,$01,$96,$43,$64,$0F,$99,$4C,$24,$08,$99,$4C,$00,$07,$99,$4C
  byte $54,$08,$99,$4C,$00,$07,$99,$4C,$44,$07,$99,$4C,$00,$07,$96,$43
  byte $00,$01,$99,$26,$74,$00,$99,$4C,$7F,$00,$96,$45,$64,$07,$99,$4C
  byte $00,$08,$99,$26,$00,$0F,$99,$26,$64,$00,$99,$4C,$74,$07,$99,$4C
  byte $00,$08,$99,$26,$00,$4A,$96,$45,$00,$01,$99,$23,$54,$00,$99,$26
  byte $64,$00,$99,$2A,$54,$00,$99,$33,$54,$00,$99,$45,$24,$00,$99,$4C
  byte $64,$00,$96,$45,$64,$07,$99,$4C,$00,$08,$99,$26,$00,$00,$99,$2A
  byte $00,$00,$99,$23,$00,$00,$99,$45,$00,$00,$99,$33,$00,$2D,$99,$33
  byte $34,$0F,$99,$33,$00,$00,$99,$4C,$24,$07,$99,$4C,$00,$08,$99,$4C
  byte $54,$08,$99,$4C,$00,$07,$99,$4C,$44,$06,$91,$26,$00,$00,$92,$3E
  byte $00,$00,$92,$45,$00,$00,$92,$42,$00,$02,$99,$4C,$00,$04,$94,$48
  byte $00,$00,$95,$3C,$00,$02,$96,$45,$00,$01,$90,$30,$7F,$00,$90,$48
  byte $7F,$00,$91,$24,$6E,$00,$92,$3E,$77,$00,$92,$41,$77,$00,$92,$45
  byte $77,$00,$93,$3C,$7F,$00,$93,$54,$7F,$00,$99,$23,$54,$00,$99,$26
  byte $74,$00,$99,$4C,$7F,$00,$96,$45,$64,$01,$94,$30,$6B,$00,$95,$24
  byte $6B,$0E,$99,$4C,$00,$00,$99,$26,$00,$00,$99,$23,$00,$08,$92,$45
  byte $00,$00,$92,$41,$00,$01,$92,$3E,$00,$19,$91,$24,$00,$0A,$96,$45
  byte $00,$01,$91,$24,$5E,$00,$92,$43,$71,$00,$99,$26,$64,$00,$99,$33
  byte $54,$00,$99,$4C,$74,$00,$96,$43,$64,$01,$92,$3C,$71,$00,$92,$40
  byte $71,$0E,$99,$4C,$00,$00,$99,$33,$00,$00,$99,$26,$00,$2C,$96,$43
  byte $00,$01,$96,$43,$64,$3B,$91,$24,$00,$00,$96,$43,$00,$01,$91,$24
  byte $5E,$00,$99,$23,$64,$00,$99,$26,$64,$00,$99,$33,$44,$00,$99,$4C
  byte $7F,$00,$96,$40,$64,$0F,$99,$4C,$00,$00,$99,$23,$00,$00,$99,$26
  byte $00,$00,$99,$33,$00,$24,$91,$24,$00,$08,$96,$40,$00,$01,$91,$24
  byte $68,$00,$99,$23,$54,$00,$99,$26,$44,$00,$99,$33,$54,$00,$99,$4C
  byte $64,$00,$96,$40,$64,$0F,$99,$4C,$00,$00,$99,$23,$00,$00,$99,$26
  byte $00,$00,$99,$33,$00,$2D,$99,$33,$44,$0F,$99,$33,$00,$0E,$91,$24
  byte $00,$01,$91,$24,$50,$00,$99,$30,$24,$00,$99,$32,$54,$0F,$99,$32
  byte $00,$00,$99,$30,$00,$09,$91,$24,$00,$05,$96,$40,$00,$01,$91,$23
  byte $5E,$00,$99,$2D,$34,$00,$99,$2F,$64,$0F,$99,$2F,$00,$00,$99,$2D
  byte $00,$2C,$91,$23,$00,$01,$91,$21,$50,$00,$99,$29,$24,$00,$99,$2B
  byte $54,$0F,$99,$2B,$00,$00,$99,$29,$00,$22,$91,$21,$00,$02,$92,$40
  byte $00,$00,$92,$3C,$00,$00,$92,$43,$00,$09,$91,$1C,$6E,$00,$92,$43
  byte $71,$00,$99,$23,$64,$00,$99,$2B,$34,$00,$99,$33,$54,$00,$96,$40
  byte $64,$01,$92,$3B,$71,$0E,$99,$33,$00,$00,$99,$2B,$00,$00,$99,$23
  byte $00,$24,$92,$3B,$00,$00,$92,$43,$00,$08,$91,$1C,$00,$00,$96,$40
  byte $00,$01,$91,$23,$5A,$00,$92,$37,$59,$00,$99,$33,$34,$00,$96,$40
  byte $64,$0F,$99,$33,$00,$09,$92,$37,$00,$1E,$91,$23,$00,$05,$96,$40
  byte $00,$01,$91,$1F,$64,$00,$92,$43,$77,$00,$99,$2A,$54,$00,$99,$33
  byte $44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$7F,$00,$96,$43
  byte $64,$01,$92,$3B,$77,$0B,$92,$3B,$00,$00,$92,$43,$00,$03,$99,$4C
  byte $00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45
  byte $00,$2B,$91,$1F,$00,$01,$96,$43,$00,$01,$91,$23,$54,$00,$92,$45
  byte $77,$00,$99,$33,$34,$00,$96,$42,$64,$01,$92,$3D,$77,$0E,$99,$33
  byte $00,$26,$91,$23,$00,$06,$96,$42,$00,$01,$91,$1C,$68,$00,$99,$33
  byte $54,$00,$96,$40,$64,$0F,$99,$33,$00,$24,$92,$3D,$00,$00,$92,$45
  byte $00,$08,$91,$1C,$00,$01,$91,$21,$5A,$00,$92,$37,$59,$00,$99,$33
  byte $34,$0F,$99,$33,$00,$09,$92,$37,$00,$1E,$91,$21,$00,$06,$91,$25
  byte $64,$00,$92,$3D,$71,$00,$92,$45,$71,$00,$99,$2A,$54,$00,$99,$33
  byte $44,$00,$99,$45,$24,$00,$99,$4C,$74,$0C,$92,$45,$00,$00,$92,$3D
  byte $00,$03,$99,$4C,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45
  byte $00,$2B,$91,$25,$00,$02,$91,$21,$50,$00,$92,$3E,$77,$00,$92,$47
  byte $77,$00,$99,$33,$34,$0F,$99,$33,$00,$26,$91,$21,$00,$06,$96,$40
  byte $00,$01,$91,$1C,$6E,$00,$99,$23,$64,$00,$99,$33,$54,$0F,$99,$33
  byte $00,$00,$99,$23,$00,$24,$92,$47,$00,$00,$92,$3E,$00,$08,$91,$1C
  byte $00,$01,$91,$23,$5A,$00,$92,$37,$59,$00,$99,$33,$34,$0F,$99,$33
  byte $00,$09,$92,$37,$00,$1E,$91,$23,$00,$06,$91,$1F,$64,$00,$92,$3E
  byte $77,$00,$92,$47,$77,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$36
  byte $64,$00,$99,$45,$34,$00,$99,$4C,$7F,$0C,$92,$47,$00,$00,$92,$3E
  byte $00,$03,$99,$4C,$00,$00,$99,$36,$00,$00,$99,$2A,$00,$00,$99,$33
  byte $00,$00,$99,$45,$00,$2B,$91,$1F,$00,$02,$91,$23,$54,$00,$92,$3D
  byte $71,$00,$92,$45,$71,$00,$99,$33,$34,$0F,$99,$33,$00,$26,$91,$23
  byte $00,$07,$91,$1C,$68,$00,$99,$33,$54,$0F,$99,$33,$00,$24,$92,$45
  byte $00,$00,$92,$3D,$00,$08,$91,$1C,$00,$01,$91,$21,$5A,$00,$92,$37
  byte $59,$00,$99,$33,$34,$0F,$99,$33,$00,$09,$92,$37,$00,$1E,$91,$21
  byte $00,$06,$91,$25,$64,$00,$92,$45,$71,$00,$99,$2A,$54,$00,$99,$33
  byte $44,$00,$99,$45,$24,$00,$99,$4C,$74,$00,$96,$40,$64,$01,$92,$3D
  byte $71,$0E,$99,$4C,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45
  byte $00,$2B,$91,$25,$00,$01,$96,$40,$00,$01,$91,$21,$50,$00,$99,$33
  byte $34,$00,$96,$3E,$64,$0F,$99,$33,$00,$24,$92,$3D,$00,$00,$92,$45
  byte $00,$02,$91,$21,$00,$06,$96,$3E,$00,$01,$FF,$06,$07,$56,$65,$72
  byte $73,$65,$20,$32,$00,$91,$1C,$6E,$00,$92,$3B,$71,$00,$92,$43,$71
  byte $00,$99,$23,$64,$00,$99,$31,$64,$00,$99,$33,$54,$00,$96,$40,$64
  byte $0F,$99,$33,$00,$00,$99,$31,$00,$00,$99,$23,$00,$24,$92,$43,$00
  byte $00,$92,$3B,$00,$08,$91,$1C,$00,$00,$96,$40,$00,$01,$91,$23,$5A
  byte $00,$92,$37,$59,$00,$99,$33,$34,$00,$96,$40,$64,$0F,$99,$33,$00
  byte $09,$92,$37,$00,$1E,$91,$23,$00,$05,$96,$40,$00,$01,$91,$1F,$64
  byte $00,$92,$3B,$77,$00,$92,$43,$77,$00,$99,$26,$64,$00,$99,$2A,$54
  byte $00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$7F
  byte $00,$96,$43,$64,$0C,$92,$43,$00,$00,$92,$3B,$00,$03,$99,$4C,$00
  byte $00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$26,$00,$00,$99,$45,$00
  byte $00,$99,$36,$00,$2B,$91,$1F,$00,$01,$96,$43,$00,$01,$91,$23,$54
  byte $00,$92,$3D,$77,$00,$92,$45,$77,$00,$99,$33,$34,$00,$96,$42,$64
  byte $0F,$99,$33,$00,$26,$91,$23,$00,$06,$96,$42,$00,$01,$91,$1C,$68
  byte $00,$99,$33,$54,$00,$96,$40,$64,$0F,$99,$33,$00,$24,$92,$45,$00
  byte $00,$92,$3D,$00,$08,$91,$1C,$00,$01,$91,$21,$5A,$00,$92,$37,$59
  byte $00,$99,$33,$34,$0F,$99,$33,$00,$09,$92,$37,$00,$1E,$91,$21,$00
  byte $06,$91,$25,$64,$00,$92,$3D,$71,$00,$92,$45,$71,$00,$99,$26,$54
  byte $00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99,$4C,$74
  byte $0C,$92,$45,$00,$00,$92,$3D,$00,$03,$99,$4C,$00,$00,$99,$33,$00
  byte $00,$99,$26,$00,$00,$99,$2A,$00,$00,$99,$45,$00,$2B,$91,$25,$00
  byte $02,$91,$21,$50,$00,$92,$3E,$77,$00,$92,$47,$77,$00,$99,$33,$34
  byte $0F,$99,$33,$00,$26,$91,$21,$00,$06,$96,$40,$00,$01,$91,$1C,$6E
  byte $00,$99,$23,$64,$00,$99,$33,$54,$0F,$99,$33,$00,$00,$99,$23,$00
  byte $24,$92,$47,$00,$00,$92,$3E,$00,$08,$91,$1C,$00,$01,$91,$23,$5A
  byte $00,$92,$37,$59,$00,$99,$33,$34,$0F,$99,$33,$00,$09,$92,$37,$00
  byte $05,$90,$30,$00,$00,$93,$3C,$00,$19,$91,$23,$00,$06,$91,$1F,$64
  byte $00,$92,$3E,$77,$00,$92,$47,$77,$00,$99,$26,$64,$00,$99,$2A,$54
  byte $00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$7F
  byte $0B,$92,$47,$00,$01,$92,$3E,$00,$03,$99,$4C,$00,$00,$99,$2A,$00
  byte $00,$99,$33,$00,$00,$99,$26,$00,$00,$99,$45,$00,$00,$99,$36,$00
  byte $2B,$91,$1F,$00,$02,$91,$23,$54,$00,$92,$3D,$71,$00,$92,$45,$71
  byte $00,$99,$33,$34,$0F,$99,$33,$00,$26,$91,$23,$00,$07,$91,$1C,$68
  byte $00,$99,$33,$54,$0F,$99,$33,$00,$24,$92,$45,$00,$00,$92,$3D,$00
  byte $08,$91,$1C,$00,$01,$91,$21,$5A,$00,$92,$37,$59,$00,$99,$33,$34
  byte $00,$96,$40,$64,$0F,$99,$33,$00,$09,$92,$37,$00,$1E,$91,$21,$00
  byte $05,$90,$48,$00,$00,$93,$54,$00,$00,$96,$40,$00,$01,$91,$25,$64
  byte $00,$92,$45,$71,$00,$99,$26,$54,$00,$99,$2A,$54,$00,$99,$33,$44
  byte $00,$99,$45,$24,$00,$99,$4C,$74,$00,$96,$40,$64,$01,$92,$3D,$71
  byte $0E,$99,$4C,$00,$00,$99,$33,$00,$00,$99,$26,$00,$00,$99,$2A,$00
  byte $00,$99,$45,$00,$2B,$91,$25,$00,$01,$96,$40,$00,$01,$91,$21,$50
  byte $00,$99,$33,$34,$00,$96,$3E,$64,$0F,$99,$33,$00,$24,$92,$3D,$00
  byte $00,$92,$45,$00,$02,$91,$21,$00,$06,$96,$3E,$00,$01,$90,$3C,$72
  byte $00,$90,$48,$72,$00,$91,$1C,$6E,$00,$92,$3B,$71,$00,$92,$43,$71
  byte $00,$93,$48,$72,$00,$93,$54,$72,$00,$99,$23,$64,$00,$99,$33,$54
  byte $00,$96,$40,$64,$0F,$99,$33,$00,$00,$99,$23,$00,$24,$92,$43,$00
  byte $00,$92,$3B,$00,$08,$91,$1C,$00,$00,$96,$40,$00,$01,$91,$23,$5A
  byte $00,$92,$37,$59,$00,$99,$33,$34,$00,$96,$40,$64,$0F,$99,$33,$00
  byte $09,$92,$37,$00,$1E,$91,$23,$00,$05,$96,$40,$00,$01,$91,$1F,$64
  byte $00,$92,$3B,$77,$00,$92,$43,$77,$00,$99,$26,$64,$00,$99,$2A,$54
  byte $00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$7F
  byte $00,$96,$43,$64,$0B,$92,$3B,$00,$01,$92,$43,$00,$03,$99,$4C,$00
  byte $00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$26,$00,$00,$99,$45,$00
  byte $00,$99,$36,$00,$2B,$91,$1F,$00,$01,$96,$43,$00,$01,$91,$23,$54
  byte $00,$92,$3D,$77,$00,$92,$45,$77,$00,$99,$33,$34,$00,$96,$43,$64
  byte $0F,$99,$33,$00,$26,$91,$23,$00,$06,$96,$43,$00,$01,$91,$1C,$68
  byte $00,$99,$33,$54,$00,$96,$40,$64,$0F,$99,$33,$00,$24,$92,$45,$00
  byte $00,$92,$3D,$00,$08,$91,$1C,$00,$01,$91,$21,$5A,$00,$92,$37,$59
  byte $00,$99,$33,$34,$0F,$99,$33,$00,$09,$92,$37,$00,$1E,$91,$21,$00
  byte $06,$91,$25,$64,$00,$92,$3D,$71,$00,$92,$45,$71,$00,$99,$26,$54
  byte $00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99,$4C,$74
  byte $0C,$92,$45,$00,$00,$92,$3D,$00,$03,$99,$4C,$00,$00,$99,$33,$00
  byte $00,$99,$26,$00,$00,$99,$2A,$00,$00,$99,$45,$00,$2B,$91,$25,$00
  byte $02,$91,$21,$50,$00,$92,$3E,$77,$00,$92,$47,$77,$00,$99,$33,$34
  byte $0F,$99,$33,$00,$26,$91,$21,$00,$06,$96,$40,$00,$01,$91,$1C,$6E
  byte $00,$99,$23,$64,$00,$99,$33,$54,$0F,$99,$33,$00,$00,$99,$23,$00
  byte $24,$92,$47,$00,$00,$92,$3E,$00,$08,$91,$1C,$00,$01,$91,$23,$5A
  byte $00,$92,$37,$59,$00,$99,$33,$34,$0F,$99,$33,$00,$09,$92,$37,$00
  byte $1E,$91,$23,$00,$06,$91,$1F,$64,$00,$92,$3E,$77,$00,$92,$47,$77
  byte $00,$99,$26,$64,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$36,$64
  byte $00,$99,$45,$34,$00,$99,$4C,$7F,$0C,$92,$47,$00,$00,$92,$3E,$00
  byte $03,$99,$4C,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$26,$00
  byte $00,$99,$45,$00,$00,$99,$36,$00,$2B,$91,$1F,$00,$02,$91,$23,$54
  byte $00,$92,$45,$71,$00,$99,$33,$34,$01,$92,$3D,$71,$0E,$99,$33,$00
  byte $26,$91,$23,$00,$07,$91,$1C,$68,$00,$99,$33,$54,$0F,$99,$33,$00
  byte $24,$92,$3D,$00,$00,$92,$45,$00,$08,$91,$1C,$00,$01,$91,$21,$5A
  byte $00,$92,$37,$59,$00,$99,$33,$34,$0F,$99,$33,$00,$09,$92,$37,$00
  byte $1E,$91,$21,$00,$06,$91,$25,$64,$00,$92,$45,$71,$00,$99,$26,$54
  byte $00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99,$4C,$74
  byte $01,$92,$3D,$71,$0E,$99,$4C,$00,$00,$99,$33,$00,$00,$99,$26,$00
  byte $00,$99,$2A,$00,$00,$99,$45,$00,$2B,$91,$25,$00,$02,$91,$21,$50
  byte $00,$99,$33,$34,$00,$96,$40,$64,$0F,$99,$33,$00,$24,$92,$3D,$00
  byte $00,$92,$45,$00,$02,$91,$21,$00,$06,$96,$40,$00,$01,$91,$21,$54
  byte $00,$92,$40,$76,$00,$92,$45,$76,$00,$94,$30,$00,$00,$94,$3C,$55
  byte $00,$95,$24,$00,$00,$95,$30,$55,$00,$99,$23,$24,$00,$99,$26,$24
  byte $00,$99,$33,$64,$00,$96,$45,$64,$01,$92,$48,$76,$0E,$99,$33,$00
  byte $00,$99,$26,$00,$00,$99,$23,$00,$08,$92,$45,$00,$00,$92,$40,$00
  byte $01,$91,$21,$00,$00,$92,$48,$00,$23,$96,$45,$00,$01,$91,$21,$46
  byte $00,$92,$45,$72,$00,$99,$23,$24,$00,$99,$26,$24,$00,$99,$33,$34
  byte $00,$96,$45,$64,$01,$92,$40,$72,$00,$92,$48,$72,$0E,$99,$33,$00
  byte $00,$99,$26,$00,$00,$99,$23,$00,$22,$91,$21,$00,$0A,$96,$45,$00
  byte $01,$91,$2D,$50,$00,$99,$23,$34,$00,$99,$26,$24,$00,$99,$2A,$54
  byte $00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$64
  byte $00,$96,$45,$64,$0F,$99,$4C,$00,$00,$99,$36,$00,$00,$99,$26,$00
  byte $00,$99,$2A,$00,$00,$99,$23,$00,$00,$99,$45,$00,$00,$99,$33,$00
  byte $2C,$96,$45,$00,$01,$99,$23,$34,$00,$99,$26,$24,$00,$99,$33,$34
  byte $00,$96,$43,$64,$0F,$99,$33,$00,$00,$99,$26,$00,$00,$99,$23,$00
  byte $27,$92,$48,$00,$00,$92,$40,$00,$00,$92,$45,$00,$05,$91,$2D,$00
  byte $00,$96,$43,$00,$01,$91,$21,$5E,$00,$92,$42,$7C,$00,$92,$47,$7C
  byte $00,$99,$23,$44,$00,$99,$26,$34,$00,$99,$33,$54,$00,$96,$45,$64
  byte $01,$92,$4A,$7C,$0E,$99,$33,$00,$00,$99,$26,$00,$00,$99,$23,$00
  byte $08,$92,$47,$00,$00,$92,$42,$00,$01,$92,$4A,$00,$07,$91,$21,$00
  byte $1D,$91,$21,$50,$00,$92,$42,$7C,$00,$92,$47,$7C,$00,$99,$23,$44
  byte $00,$99,$26,$34,$00,$99,$33,$34,$01,$92,$4A,$7C,$0E,$99,$33,$00
  byte $00,$99,$26,$00,$00,$99,$23,$00,$22,$91,$21,$00,$0B,$91,$2D,$5A
  byte $00,$99,$23,$54,$00,$99,$26,$34,$00,$99,$2A,$54,$00,$99,$33,$44
  byte $00,$99,$45,$24,$00,$99,$4C,$54,$0F,$99,$4C,$00,$00,$99,$26,$00
  byte $00,$99,$2A,$00,$00,$99,$23,$00,$00,$99,$45,$00,$00,$99,$33,$00
  byte $2D,$99,$23,$54,$00,$99,$26,$34,$00,$99,$33,$34,$0F,$99,$33,$00
  byte $00,$99,$26,$00,$00,$99,$23,$00,$27,$92,$4A,$00,$00,$92,$47,$00
  byte $00,$92,$42,$00,$05,$91,$2D,$00,$00,$96,$45,$00,$01,$91,$21,$64
  byte $00,$92,$43,$7F,$00,$99,$23,$64,$00,$99,$26,$44,$00,$99,$33,$64
  byte $01,$92,$48,$7F,$00,$92,$4C,$7F,$0E,$99,$33,$00,$00,$99,$26,$00
  byte $00,$99,$23,$00,$08,$92,$43,$00,$01,$92,$4C,$00,$00,$92,$48,$00
  byte $0D,$91,$21,$00,$17,$91,$21,$5A,$00,$92,$48,$7C,$00,$99,$23,$64
  byte $00,$99,$26,$44,$00,$99,$33,$34,$01,$92,$43,$7C,$00,$92,$4C,$7C
  byte $0E,$99,$33,$00,$00,$99,$26,$00,$00,$99,$23,$00,$25,$91,$21,$00
  byte $08,$91,$2D,$64,$00,$99,$23,$64,$00,$99,$26,$44,$00,$99,$2A,$54
  byte $00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$64
  byte $0F,$99,$4C,$00,$00,$99,$36,$00,$00,$99,$26,$00,$00,$99,$2A,$00
  byte $00,$99,$23,$00,$00,$99,$45,$00,$00,$99,$33,$00,$2D,$99,$23,$74
  byte $00,$99,$26,$44,$00,$99,$33,$34,$0F,$99,$33,$00,$00,$99,$26,$00
  byte $00,$99,$23,$00,$27,$92,$4C,$00,$00,$92,$43,$00,$00,$92,$48,$00
  byte $05,$90,$48,$00,$00,$90,$3C,$00,$00,$91,$2D,$00,$00,$93,$54,$00
  byte $00,$93,$48,$00,$01,$91,$21,$72,$00,$92,$4A,$7F,$00,$92,$4E,$7F
  byte $00,$99,$23,$74,$00,$99,$26,$54,$00,$99,$33,$54,$01,$92,$45,$7F
  byte $0E,$99,$33,$00,$00,$99,$26,$00,$00,$99,$23,$00,$08,$92,$4E,$00
  byte $00,$92,$4A,$00,$01,$92,$45,$00,$14,$91,$21,$00,$10,$91,$21,$64
  byte $00,$92,$45,$7F,$00,$92,$4E,$7F,$00,$99,$23,$74,$00,$99,$26,$54
  byte $00,$99,$33,$34,$01,$92,$4A,$7F,$0E,$99,$33,$00,$00,$99,$26,$00
  byte $00,$99,$23,$00,$27,$91,$21,$00,$06,$91,$2D,$72,$00,$99,$23,$7F
  byte $00,$99,$26,$64,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$45,$24
  byte $00,$99,$4C,$54,$0F,$99,$4C,$00,$00,$99,$26,$00,$00,$99,$2A,$00
  byte $00,$99,$23,$00,$00,$99,$45,$00,$00,$99,$33,$00,$2B,$91,$2D,$00
  byte $02,$91,$21,$5A,$00,$99,$23,$7F,$00,$99,$26,$74,$00,$99,$33,$34
  byte $0F,$99,$33,$00,$00,$99,$26,$00,$00,$99,$23,$00,$26,$91,$21,$00
  byte $01,$92,$4A,$00,$00,$92,$4E,$00,$00,$92,$45,$00,$06,$90,$48,$78
  byte $00,$90,$54,$78,$00,$91,$1C,$6E,$00,$92,$43,$71,$00,$93,$54,$78
  byte $00,$93,$60,$78,$00,$99,$23,$64,$00,$99,$33,$54,$00,$96,$40,$64
  byte $01,$92,$3B,$71,$0E,$99,$33,$00,$00,$99,$23,$00,$24,$92,$3B,$00
  byte $00,$92,$43,$00,$08,$91,$1C,$00,$00,$96,$40,$00,$01,$91,$23,$5A
  byte $00,$92,$37,$59,$00,$99,$33,$34,$00,$96,$40,$64,$0F,$99,$33,$00
  byte $09,$92,$37,$00,$1E,$91,$23,$00,$05,$96,$40,$00,$01,$91,$1F,$64
  byte $00,$92,$3B,$77,$00,$92,$43,$77,$00,$99,$26,$64,$00,$99,$2A,$54
  byte $00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$7F
  byte $00,$96,$43,$64,$0C,$92,$43,$00,$00,$92,$3B,$00,$03,$99,$4C,$00
  byte $00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$26,$00,$00,$99,$45,$00
  byte $00,$99,$36,$00,$2B,$91,$1F,$00,$01,$96,$43,$00,$01,$91,$23,$54
  byte $00,$92,$3D,$77,$00,$92,$45,$77,$00,$99,$33,$34,$00,$96,$43,$64
  byte $0F,$99,$33,$00,$26,$91,$23,$00,$06,$96,$43,$00,$01,$91,$1C,$68
  byte $00,$99,$33,$54,$00,$96,$40,$64,$0F,$99,$33,$00,$24,$92,$45,$00
  byte $00,$92,$3D,$00,$08,$91,$1C,$00,$01,$91,$21,$5A,$00,$92,$37,$59
  byte $00,$99,$33,$34,$0F,$99,$33,$00,$09,$92,$37,$00,$1E,$91,$21,$00
  byte $06,$91,$25,$64,$00,$92,$3D,$71,$00,$92,$45,$71,$00,$99,$26,$54
  byte $00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$45,$24,$00,$99,$4C,$74
  byte $0C,$92,$45,$00,$00,$92,$3D,$00,$03,$99,$4C,$00,$00,$99,$33,$00
  byte $00,$99,$26,$00,$00,$99,$2A,$00,$00,$99,$45,$00,$2B,$91,$25,$00
  byte $02,$91,$21,$50,$00,$92,$3E,$77,$00,$92,$47,$77,$00,$99,$33,$34
  byte $0F,$99,$33,$00,$26,$91,$21,$00,$06,$96,$40,$00,$01,$91,$1C,$6E
  byte $00,$99,$23,$64,$00,$99,$33,$54,$0F,$99,$33,$00,$00,$99,$23,$00
  byte $23,$92,$3E,$00,$01,$92,$47,$00,$08,$91,$1C,$00,$01,$91,$23,$5A
  byte $00,$92,$37,$59,$00,$99,$33,$34,$0F,$99,$33,$00,$09,$92,$37,$00
  byte $1E,$91,$23,$00,$06,$91,$1F,$64,$00,$92,$3E,$77,$00,$99,$26,$64
  byte $00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34
  byte $00,$99,$4C,$7F,$01,$92,$47,$77,$0B,$92,$47,$00,$00,$92,$3E,$00
  byte $03,$99,$4C,$00,$00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$26,$00
  byte $00,$99,$45,$00,$00,$99,$36,$00,$2B,$91,$1F,$00,$02,$91,$23,$54
  byte $00,$92,$3D,$71,$00,$92,$45,$71,$00,$99,$33,$34,$0F,$99,$33,$00
  byte $26,$91,$23,$00,$07,$91,$1C,$68,$00,$99,$33,$54,$0F,$99,$33,$00
  byte $23,$92,$3D,$00,$01,$92,$45,$00,$08,$91,$1C,$00,$01,$91,$21,$5A
  byte $00,$92,$37,$59,$00,$99,$33,$34,$0F,$99,$33,$00,$09,$92,$37,$00
  byte $1E,$91,$21,$00,$06,$91,$25,$64,$00,$92,$3D,$71,$00,$92,$45,$71
  byte $00,$99,$26,$54,$00,$99,$2A,$54,$00,$99,$33,$44,$00,$99,$45,$24
  byte $00,$99,$4C,$74,$00,$96,$40,$64,$0F,$99,$4C,$00,$00,$99,$33,$00
  byte $00,$99,$26,$00,$00,$99,$2A,$00,$00,$99,$45,$00,$2B,$91,$25,$00
  byte $01,$96,$40,$00,$01,$91,$21,$50,$00,$99,$33,$34,$00,$96,$40,$64
  byte $0F,$99,$33,$00,$23,$92,$3D,$00,$01,$92,$45,$00,$02,$91,$21,$00
  byte $06,$96,$40,$00,$01,$91,$26,$6E,$00,$92,$43,$7B,$00,$92,$47,$7B
  byte $00,$92,$3E,$7B,$00,$99,$23,$64,$00,$99,$33,$64,$00,$96,$47,$64
  byte $0F,$99,$33,$00,$00,$99,$23,$00,$2C,$96,$47,$00,$01,$96,$45,$64
  byte $01,$92,$47,$00,$01,$92,$3E,$00,$00,$92,$43,$00,$25,$91,$26,$00
  byte $14,$96,$45,$00,$01,$91,$26,$6E,$00,$92,$42,$7B,$00,$92,$3E,$7B
  byte $00,$92,$45,$7B,$00,$99,$23,$64,$00,$99,$2A,$54,$00,$99,$33,$64
  byte $00,$99,$36,$64,$00,$99,$45,$34,$00,$96,$45,$64,$0F,$99,$45,$00
  byte $00,$99,$33,$00,$00,$99,$23,$00,$00,$99,$2A,$00,$00,$99,$36,$00
  byte $2C,$96,$45,$00,$01,$96,$43,$64,$0F,$99,$4C,$24,$08,$99,$4C,$00
  byte $07,$99,$4C,$54,$07,$99,$4C,$00,$08,$99,$4C,$44,$07,$99,$4C,$00
  byte $07,$96,$43,$00,$01,$99,$26,$74,$00,$99,$4C,$7F,$00,$96,$45,$64
  byte $07,$99,$4C,$00,$08,$99,$26,$00,$0F,$99,$26,$64,$00,$99,$4C,$7F
  byte $07,$99,$4C,$00,$08,$99,$26,$00,$4A,$96,$45,$00,$01,$92,$45,$00
  byte $00,$92,$3E,$00,$00,$92,$42,$00,$00,$92,$42,$7B,$00,$92,$3E,$7B
  byte $00,$92,$45,$7B,$00,$99,$23,$44,$00,$99,$26,$64,$00,$99,$2A,$54
  byte $00,$99,$33,$54,$00,$99,$45,$24,$00,$99,$4C,$74,$00,$96,$45,$64
  byte $08,$99,$4C,$00,$07,$99,$26,$00,$00,$99,$2A,$00,$00,$99,$23,$00
  byte $00,$99,$45,$00,$00,$99,$33,$00,$2D,$99,$26,$64,$00,$99,$33,$34
  byte $0F,$99,$33,$00,$00,$99,$26,$00,$00,$99,$4C,$24,$07,$99,$4C,$00
  byte $08,$99,$26,$44,$00,$99,$4C,$54,$08,$99,$4C,$00,$07,$99,$26,$00
  byte $00,$99,$4C,$44,$06,$91,$26,$00,$02,$99,$4C,$00,$06,$96,$45,$00
  byte $01,$91,$24,$6E,$00,$92,$45,$00,$00,$92,$3E,$00,$00,$92,$42,$00
  byte $00,$92,$3C,$7F,$00,$92,$40,$7F,$00,$92,$43,$7F,$00,$99,$23,$54
  byte $00,$99,$26,$64,$00,$99,$4C,$7F,$00,$96,$43,$64,$0F,$99,$4C,$00
  byte $00,$99,$26,$00,$00,$99,$23,$00,$22,$91,$24,$00,$0A,$96,$43,$00
  byte $01,$91,$24,$5E,$00,$92,$43,$00,$00,$92,$40,$00,$00,$92,$3C,$00
  byte $00,$92,$3C,$7F,$00,$92,$40,$7F,$00,$92,$43,$7F,$00,$99,$26,$64
  byte $00,$99,$33,$54,$00,$99,$4C,$74,$00,$96,$43,$64,$0F,$99,$4C,$00
  byte $00,$99,$33,$00,$00,$99,$26,$00,$2C,$96,$43,$00,$01,$96,$43,$64
  byte $3B,$91,$24,$00,$00,$96,$43,$00,$01,$91,$24,$5E,$00,$99,$23,$64
  byte $00,$99,$26,$64,$00,$99,$33,$44,$00,$99,$4C,$7F,$00,$96,$40,$64
  byte $0F,$99,$4C,$00,$00,$99,$23,$00,$00,$99,$26,$00,$00,$99,$33,$00
  byte $24,$91,$24,$00,$08,$90,$54,$00,$00,$90,$48,$00,$00,$93,$60,$00
  byte $00,$93,$54,$00,$00,$96,$40,$00,$01,$91,$24,$68,$00,$92,$43,$00
  byte $00,$92,$40,$00,$00,$92,$3C,$00,$00,$92,$3C,$7F,$00,$92,$40,$7F
  byte $00,$92,$43,$7F,$00,$99,$23,$54,$00,$99,$26,$44,$00,$99,$33,$54
  byte $00,$99,$4C,$64,$00,$96,$40,$64,$0F,$99,$4C,$00,$00,$99,$23,$00
  byte $00,$99,$26,$00,$00,$99,$33,$00,$2D,$99,$33,$44,$0F,$99,$33,$00
  byte $0E,$91,$24,$00,$01,$91,$24,$50,$00,$99,$30,$24,$00,$99,$32,$64
  byte $0F,$99,$32,$00,$00,$99,$30,$00,$09,$91,$24,$00,$05,$96,$40,$00
  byte $01,$91,$23,$5E,$00,$99,$2D,$34,$00,$99,$2F,$74,$0F,$99,$2F,$00
  byte $00,$99,$2D,$00,$2C,$91,$23,$00,$01,$91,$21,$50,$00,$99,$29,$24
  byte $00,$99,$2B,$64,$0F,$99,$2B,$00,$00,$99,$29,$00,$22,$91,$21,$00
  byte $0B,$91,$1C,$6E,$00,$92,$43,$00,$00,$92,$40,$00,$00,$92,$3C,$00
  byte $00,$92,$3B,$71,$00,$92,$43,$71,$00,$94,$3C,$54,$00,$95,$30,$54
  byte $00,$99,$23,$54,$00,$99,$31,$64,$00,$99,$33,$54,$00,$96,$40,$64
  byte $0F,$99,$33,$00,$00,$99,$31,$00,$00,$99,$23,$00,$24,$92,$43,$00
  byte $00,$92,$3B,$00,$08,$91,$1C,$00,$00,$96,$40,$00,$01,$91,$23,$5A
  byte $00,$92,$37,$59,$00,$99,$33,$34,$00,$96,$40,$64,$0F,$99,$33,$00
  byte $09,$92,$37,$00,$1E,$91,$23,$00,$05,$96,$40,$00,$01,$91,$1F,$64
  byte $00,$92,$3B,$77,$00,$92,$43,$77,$00,$99,$26,$64,$00,$99,$2A,$54
  byte $00,$99,$33,$44,$00,$99,$36,$64,$00,$99,$45,$34,$00,$99,$4C,$7F
  byte $00,$96,$43,$64,$0C,$92,$43,$00,$00,$92,$3B,$00,$03,$99,$4C,$00
  byte $00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$26,$00,$00,$99,$45,$00
  byte $00,$99,$36,$00,$2B,$91,$1F,$00,$01,$96,$43,$00,$01,$91,$23,$54
  byte $00,$92,$3D,$77,$00,$92,$45,$77,$00,$99,$33,$34,$00,$96,$43,$64
  byte $0F,$99,$00,$00,$26,$91,$23,$00,$06,$96,$43,$00,$01,$90,$3C,$00
  byte $00,$90,$54,$00,$00,$91,$1C,$00,$00,$93,$48,$00,$00,$93,$60,$00
  byte $00,$99,$33,$00,$00,$96,$40,$00,$0F,$99,$33,$00,$24,$92,$45,$00
  byte $00,$92,$3D,$00,$08,$91,$1C,$00,$01,$91,$21,$00,$00,$92,$37,$00
  byte $00,$99,$33,$00,$0F,$99,$33,$00,$09,$92,$37,$00,$1E,$91,$21,$00
  byte $06,$91,$25,$00,$00,$92,$3D,$00,$00,$92,$45,$00,$00,$99,$26,$00
  byte $00,$99,$2A,$00,$00,$99,$33,$00,$00,$99,$45,$00,$00,$99,$4C,$00
  byte $0C,$92,$3D,$00,$01,$92,$45,$00,$02,$99,$4C,$00,$00,$99,$33,$00
  byte $00,$99,$26,$00,$00,$99,$2A,$00,$00,$99,$45,$00

    